%
% Matlab commands to plot particles released from a vertical xz
%   sheet across 60m isobath.  There are hardwires in this code!!
%
%   The particles are plotted relative to the transect where they
%      were released.  The full 3-D trajectories are used, and the
%      plot is always of particle-position relative to its closest
%      distance to the 60m isobath.  The particles do not reside 
%      anymore in the original xz plane, but we assume that the
%      downstream section does not change too much - this will
%      be violated in some cases.
%
%   Input: DRIFTERS.pth
%          bank150
%          pairs60m.dat (unordered xy points of 60m contour)
%          ITER*icq4 files used to make the DRIFTERS.pth file
%
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%             be careful that the first icq4 available is the
%             first icq4 used in the calculation of DRIFTERS.pth 
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%

b=loadgrid('bank150');
P=read_pth('/mnt/ljaz/May20_FCAST/PSQ4_FCAST/OBS/DRIFTERS',4);

%
% FRONT RELATED READS AND INITIALIZATIONS  (HARDWIRE!!!)
%


% (x,y) coordinates of "particle release sheet" the vertical plane transect
%
xytrans=1.0e+05*[2.88622872498780  -1.15111494059523             
                 3.12220077045220  -1.63416908969477];
		 
% compute distance of the on-bank coordinate to the 60m isobath
%
iso60=load('pairs60m.dat');
xto60=zeros(length(iso60),1);
yto60=zeros(length(iso60),1);
dto60=zeros(length(iso60),1);
eye=sqrt(-1.);

for id=1:length(iso60)
   xto60(id)=xytrans(1,1)-iso60(id,1);
   yto60(id)=xytrans(1,2)-iso60(id,2);
   dto60(id)=abs(xto60(id)+eye*yto60(id));
end

% distx1 is the distance from the top of the transect to the 60m isobath
%
distx1=min(dto60);   
distkm=distx1/1000

% get list of icq4 files
%
%  WARNING: make sure the first icq4 read in this file is the
%     first one used in the calculation of DRIFTERS.pth
%
D=dirsort('ITER*.icq4');
NFILE=length(D);

%   DRIFTER RELATED INITIALIZATIONS
%

% line up drifter start with proper icq4
%
% iter1=0000 will work if the first icq4 read in this file is the
%     first one used in the calculation of DRIFTERS.pth
%     This needs to be generalized
%
iter1=0000;                   % start of model output dt iter
itph=1;                       % iter'n per hour=1 (PSQ4 computed hourly pos'n)

for in=1:NFILE                % loop over the icq4 files
  
    in                        % write to screen to see where we are
      
    clf
	
% plot frontal Temp structure	
%
    icq4=read_icq4(D(in).name);
    transect(icq4,b,[xytrans(1,1) xytrans(2,1)], ...
                    [xytrans(1,2) xytrans(2,2)],2000,'TMPMID',0)
    set(gca,'clim',[6 10])
    colorbar

% place time-text on figure
%        
    text(5000,-80,'May','FontSize',15);
    tday=num2str(icq4.day);
    text(11000,-80,tday,'FontSize',15);
    thours=100*icq4.curr_seconds/3600;
    strhours=num2str(thours);
    text(16000,-80,strhours,'FontSize',15);
    text(23000,-80,'GMT','FontSize',15);
    
    hold on
	
% Compute particle distances to the 60m isobath.	
%  Note that the particles will move out of the 
%  initial vertical plane but their position within the
%  initial vertical plane will be plotted relative to the 60m
%  isobath.  This distance is computed every time for each particle
%  relative to its nearest 60m contour.  This way we can consider 
%  the convergence (or not) relative to this isobath.
%

    istart=1+(iter1+(in-1)*itph)*P.ndrog;  % starting counter in the pth file
    iend=istart+P.ndrog-1;                 % ending counter for this time block

    drogto60=zeros(length(iso60),1);       % distance of one drog to each point
    indx60=zeros(P.ndrog,1);        
    minto60=zeros(P.ndrog,1);

% for this time step, compute the distances for each particle to the
%    60m isobath
%
    icnt=0;
    for id=istart:iend                           % for each block of drogs
       icnt=icnt+1;
       for i60=1:length(iso60)                   % for each point of the 60m
          xi60=P.pth(id,1)-iso60(i60,1);         % x's relative 60m contour
          yi60=P.pth(id,2)-iso60(i60,2);         % y's relative 60m contour
          drogto60(i60,1)=abs(xi60+eye*yi60);    % dist's to 60m contour
       end
       minto60(icnt,1)=min(drogto60);            % compute min distance
       iii=find(drogto60(:,1)==minto60(icnt,1)); % find index(es)
%      if length(iii)~=1
%        sprintf('More than one min distance found - choosing 1st one')
%      end
       indx60(icnt,1)=iii(1);                    % save index
    end

% Find if drog is seaward or shoalward of the 60m isobath
%   if it's seaward sideof60, it is less than zero (defined by P.pth-iso60)
%   if it's shoalward sideof60, it is greater than zero
%      The decision is based on the y-coord for the particular case of
%      the 60m isobath on the southern flank of GB - in this sense this
%      is a hardwire.  Re-think this with a vector cross-product check.
%
    dist=zeros(P.ndrog,1);
    icnt=0;
    for id=istart:iend                          % for each block of drogs
       icnt=icnt+1;
       sideof60=P.pth(id,2)-iso60(indx60(icnt,1),2);         % base on y coord
       distnc(icnt,1)=distx1-sign(sideof60)*minto60(icnt,1); % dist for plot
    end
   
% get the depth of the drogues
%
    z=P.pth(istart:iend,3);
   
   
% plot positions
%
%    for id=1:P.ndrog
%       plot(distnc(id),z(id),'.','MarkerSize',20,'Color','k')
%    end	


% these commands work for this particular case - another hardwire
%
     plot(distnc(1:10),z(1:10),'.','MarkerSize',20,'Color','w')    %  5m
     plot(distnc(11:20),z(11:20),'.','MarkerSize',20,'Color','y')  % 10m
     plot(distnc(21:30),z(21:30),'.','MarkerSize',20,'Color','g')  % 15m
     plot(distnc(31:40),z(31:40),'.','MarkerSize',20,'Color','c')  % 20m
     plot(distnc(41:50),z(41:50),'.','MarkerSize',20,'Color','m')  % 25m
     plot(distnc(51:60),z(51:60),'.','MarkerSize',20,'Color','b')  % 30m
     plot(distnc(61:70),z(61:70),'.','MarkerSize',20,'Color','r')  % 35m
     plot(distnc(71:80),z(71:80),'.','MarkerSize',20,'Color','k')  % 40m
     plot(distnc(81:length(z)),z(81:length(z)),'.','MarkerSize',20,'Color','k')
     
     
% change name below for new case
%
        fname=sprintf('fr_relMay20_t%.0f.ppm',in)
        print('-dppm',fname) 
	
	!compress *.ppm
   
        hold off
	
end
